import React, { useState, useEffect } from 'react';
import { Helmet } from 'react-helmet';
import CastReceiver from '../interfaces/CastReceiver';
import castContext from '../context/castContext';
import toWait from '../helpers/toWait';
type CastProviderProps = {
  children: any;
};

const CastProvider = ({ children }: CastProviderProps) => {
  const [cast, setCast] = useState<{
    castReceiver?: CastReceiver;
    castSender?: any;
  }>({});

  const [session, setSession] = useState<any>({});

  useEffect(() => {
    (async () => {
      let toBreak = false;
      let tries = 15;
      let castReceiver: CastReceiver;
      let castSender: any;
      while (true) {
        try {
          // @ts-ignore
          castReceiver = window.chrome.cast as CastReceiver;
          // @ts-ignore
          castSender = window.cast.framework as any;
          toBreak = true;
        } catch (err) {
          tries--;
          if (!tries) {
            toBreak = true;
          }
        } finally {
          if (toBreak) break;
        }
        await toWait(95);
      }
      // @ts-ignore
      if (tries !== 0 && !!castReceiver) {
        setCast({
          castReceiver,
          castSender,
        });
      } else {
        throw new Error("Can't Load castReceiver and\\or castSender");
      }
    })();
  }, []);

  return (
    <>
      <Helmet>
        <script src="//www.gstatic.com/cv/js/sender/v1/cast_sender.js?loadCastFramework=1" />
        <script src="//www.gstatic.com/cast/sdk/libs/receiver/2.0.0/cast_receiver.js" />
        <script src="//imasdk.googleapis.com/js/sdkloader/ima3.js"></script>
      </Helmet>
      <castContext.Provider
        value={{
          ...cast,
          session,
          setSession,
        }}
      >
        {children}
      </castContext.Provider>
    </>
  );
};

export default CastProvider;
